@@ -542,6 +542,7 @@ def assign_model(model,
     return data__
 
 
+
 def tune_model(model=None,
                supervised_target=None,
                method = 'drop',
@@ -1126,7 +1127,7 @@ def tune_model(model=None,
         monitor.iloc[1,1:] = 'Finalizing'
         update_display(monitor, display_id = 'monitor')
                              
-        df = pd.DataFrame({'Fraction': param_grid_with_zero, 'Accuracy' : acc, 'AUC' : auc, 'Recall' : recall, 
+        df = pd.DataFrame({'Fraction %': param_grid_with_zero, 'Accuracy' : acc, 'AUC' : auc, 'Recall' : recall, 
                    'Precision' : prec, 'F1' : f1, 'Kappa' : kappa})
         
         sorted_df = df.sort_values(by=optimize, ascending=False)
@@ -1135,10 +1136,10 @@ def tune_model(model=None,
         best_model = master[ival]
         best_model_df = master_df[ival]
         progress.value += 1 
-        sd = pd.melt(df, id_vars=['Fraction'], value_vars=['Accuracy', 'AUC', 'Recall', 'Precision', 'F1', 'Kappa'], 
+        sd = pd.melt(df, id_vars=['Fraction %'], value_vars=['Accuracy', 'AUC', 'Recall', 'Precision', 'F1', 'Kappa'], 
                      var_name='Metric', value_name='Score')
 
-        fig = px.line(sd, x='Fraction', y='Score', color='Metric', line_shape='linear', range_y = [0,1])
+        fig = px.line(sd, x='Fraction %', y='Score', color='Metric', line_shape='linear', range_y = [0,1])
         fig.update_layout(plot_bgcolor='rgb(245,245,245)')
         title= str(full_name) + ' Metrics and Fraction %'
         fig.update_layout(title={'text': title, 'y':0.95,'x':0.45,'xanchor': 'center','yanchor': 'top'})
@@ -1147,7 +1148,7 @@ def tune_model(model=None,
 
         fig.show()
         
-        best_k = np.array(sorted_df.head(1)['Fraction'])[0]
+        best_k = np.array(sorted_df.head(1)['Fraction %'])[0]
         best_m = round(np.array(sorted_df.head(1)[optimize])[0],4)
         p = 'Best Model: ' + model_name + ' |' + ' Fraction %: ' + str(best_k) + ' | ' + str(optimize) + ' : ' + str(best_m)
         print(p)
@@ -1462,6 +1463,7 @@ def tune_model(model=None,
     return best_model
     
 
+
 def plot_model(model,
                plot = 'tsne'):
     
